public inbox for gnats-devel@sourceware.org
 help / color / mirror / Atom feed
* Very small bug
@ 2003-01-08  1:18 Dieperink Alwin
  2003-01-08 13:13 ` Yngve Svendsen
  2003-01-08 13:38 ` Lars Henriksen
  0 siblings, 2 replies; 5+ messages in thread
From: Dieperink Alwin @ 2003-01-08  1:18 UTC (permalink / raw)
  To: 'yngve.svendsen@sun.com'; +Cc: 'help-gnats@gnu.org'

Hi Yngve,

Here is a small correction for gnatsweb.pl. Without this, gnatsweb writes a
warning in the logfile.

Regards,
-- Alwin


1362c1362
<            && ($2 !=~ "compatible") )
---
>            && ($2 !~ "compatible") )


_______________________________________________
Help-gnats mailing list
Help-gnats@gnu.org
http://mail.gnu.org/mailman/listinfo/help-gnats

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: Very small bug
  2003-01-08  1:18 Very small bug Dieperink Alwin
@ 2003-01-08 13:13 ` Yngve Svendsen
  2003-01-08 13:38 ` Lars Henriksen
  1 sibling, 0 replies; 5+ messages in thread
From: Yngve Svendsen @ 2003-01-08 13:13 UTC (permalink / raw)
  To: Dieperink Alwin; +Cc: 'help-gnats@gnu.org'

At 19:35 06.01.2003 +0100, Dieperink Alwin wrote:
>Hi Yngve,
>
>Here is a small correction for gnatsweb.pl. Without this, gnatsweb writes a
>warning in the logfile.

Thanks. Committed.

- Yngve 



_______________________________________________
Help-gnats mailing list
Help-gnats@gnu.org
http://mail.gnu.org/mailman/listinfo/help-gnats

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: Very small bug
  2003-01-08  1:18 Very small bug Dieperink Alwin
  2003-01-08 13:13 ` Yngve Svendsen
@ 2003-01-08 13:38 ` Lars Henriksen
  2003-01-08 13:58   ` Yngve Svendsen
  2003-04-29 19:56   ` Yngve Svendsen
  1 sibling, 2 replies; 5+ messages in thread
From: Lars Henriksen @ 2003-01-08 13:38 UTC (permalink / raw)
  To: Dieperink Alwin
  Cc: 'help-gnats@gnu.org', 'yngve.svendsen@sun.com'

On Mon, Jan 06, 2003 at 07:35:03PM +0100, Dieperink Alwin wrote:
> Hi Yngve,
> 
> Here is a small correction for gnatsweb.pl. Without this, gnatsweb writes a
> warning in the logfile.
> 
> Regards,
> -- Alwin
> 
> 
> 1362c1362
> <            && ($2 !=~ "compatible") )
> ---
> >            && ($2 !~ "compatible") )

There's more. Opera (at least version 6.04) also doesn't like the double
encoding.

Lars Henriksen

diff -u -r1.120 gnatsweb.pl
--- gnatsweb.pl 8 Jan 2003 13:04:17 -0000       1.120
+++ gnatsweb.pl 8 Jan 2003 13:28:06 -0000
@@ -1357,9 +1357,10 @@
   my $body    = $q->escape(get_viewpr_url($pr));
 
   # Netscape Navigator up to and including 4.x should get the URL in
-  # the body encoded only once
-  unless ( ($ENV{'HTTP_USER_AGENT'} =~ "Mozilla\/(.)(.*)") && ($1 < 5)
-           && ($2 !~ "compatible") )
+  # the body encoded only once--and so should Opera.
+  unless (
+     ( $ENV{'HTTP_USER_AGENT'} =~ "Mozilla\/(.)(.*)" && $1 < 5 && $2 !~ "compatible" )
+    || $ENV{'HTTP_USER_AGENT'} =~ "Opera\/" )
   {
     $body = $q->escape($body);
   }


_______________________________________________
Help-gnats mailing list
Help-gnats@gnu.org
http://mail.gnu.org/mailman/listinfo/help-gnats

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: Very small bug
  2003-01-08 13:38 ` Lars Henriksen
@ 2003-01-08 13:58   ` Yngve Svendsen
  2003-04-29 19:56   ` Yngve Svendsen
  1 sibling, 0 replies; 5+ messages in thread
From: Yngve Svendsen @ 2003-01-08 13:58 UTC (permalink / raw)
  To: Lars Henriksen, Dieperink Alwin; +Cc: 'help-gnats@gnu.org'

At 14:31 08.01.2003 +0100, Lars Henriksen wrote:
>There's more. Opera (at least version 6.04) also doesn't like the double
>encoding.

Ouch. Mailto encoding is a well known troublemaker, and there seems to be 
an infinite number of combinations of mail clients and web browsers that 
all require different encodings. Anyone have any better ideas?

- Yngve 



_______________________________________________
Help-gnats mailing list
Help-gnats@gnu.org
http://mail.gnu.org/mailman/listinfo/help-gnats

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: Very small bug
  2003-01-08 13:38 ` Lars Henriksen
  2003-01-08 13:58   ` Yngve Svendsen
@ 2003-04-29 19:56   ` Yngve Svendsen
  1 sibling, 0 replies; 5+ messages in thread
From: Yngve Svendsen @ 2003-04-29 19:56 UTC (permalink / raw)
  To: Lars Henriksen, Dieperink Alwin; +Cc: 'help-gnats@gnu.org'

At 14:31 08.01.2003 +0100, Lars Henriksen wrote:
>On Mon, Jan 06, 2003 at 07:35:03PM +0100, Dieperink Alwin wrote:
> > Hi Yngve,
> >
> > Here is a small correction for gnatsweb.pl. Without this, gnatsweb writes a
> > warning in the logfile.
> >
> > Regards,
> > -- Alwin
> >
> >
> > 1362c1362
> > <            && ($2 !=~ "compatible") )
> > ---
> > >            && ($2 !~ "compatible") )
>
>There's more. Opera (at least version 6.04) also doesn't like the double
>encoding.

I committed the fix for Opera. "Advanced" mailto links are really a 
horrible mess since browsers decode them differently, and mail clients may 
also handle them in different ways.

- Yngve 



_______________________________________________
Help-gnats mailing list
Help-gnats@gnu.org
http://mail.gnu.org/mailman/listinfo/help-gnats

^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2003-04-29 19:56 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2003-01-08  1:18 Very small bug Dieperink Alwin
2003-01-08 13:13 ` Yngve Svendsen
2003-01-08 13:38 ` Lars Henriksen
2003-01-08 13:58   ` Yngve Svendsen
2003-04-29 19:56   ` Yngve Svendsen

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).